/*-
 * %%----------------------------------------------------------------------------------------------
 * Solidify Framework - Solidify Index Controller - IndexFielAliasRemoteResourceService.java
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

package ch.unige.solidify.service.rest.abstractservice;

import java.util.ArrayList;
import java.util.List;

import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;

import ch.unige.solidify.IndexConstants;
import ch.unige.solidify.dto.LabelDTO;
import ch.unige.solidify.model.Label;
import ch.unige.solidify.model.index.FacetProperties;
import ch.unige.solidify.model.index.IndexFieldAlias;
import ch.unige.solidify.rest.RestCollectionPage;
import ch.unige.solidify.service.RemoteResourceService;
import ch.unige.solidify.service.SolidifyRestClientService;
import ch.unige.solidify.util.StringTool;

public abstract class IndexFielAliasRemoteResourceService extends RemoteResourceService<IndexFieldAlias> {

  private final String indexUrl;

  protected IndexFielAliasRemoteResourceService(String rootContext, SolidifyRestClientService restClientService) {
    super(restClientService);
    this.indexUrl = rootContext + "/" + IndexConstants.INDEX_MODULE;
  }

  @Override
  protected Class<IndexFieldAlias> getResourceClass() {
    return IndexFieldAlias.class;
  }

  @Override
  protected String getResourceUrl() {
    return this.indexUrl + "/" + IndexConstants.INDEX_FIELD_ALIASES;
  }

  public List<FacetProperties> getFacetProperties(String index) {
    List<FacetProperties> list = new ArrayList<>();
    for (final IndexFieldAlias field : this
            .findAll(PageRequest.of(0, RestCollectionPage.MAX_SIZE_PAGE, Sort.by(IndexConstants.FACET_ORDER_FIELD))).getData()) {
      if (field.getIndexName().equals(index)) {
        FacetProperties facetProperties = new FacetProperties();
        facetProperties.setName(field.getAlias());
        facetProperties.setDefaultVisibleValues(field.getFacetDefaultVisibleValues());
        for (Label label : field.getLabels()) {
          String text = label.getText();
          if (StringTool.isNullOrEmpty(text)) {
            text = field.getAlias();
          }
          facetProperties.getLabels().add(new LabelDTO(text, label.getLanguage().getCode()));
        }
        list.add(facetProperties);
      }
    }
    return list;
  }

}
